summaryrefslogtreecommitdiff
path: root/setfacl
diff options
context:
space:
mode:
authorNathan Scott <nathans@sgi.com>2002-09-06 03:15:41 +0000
committerNathan Scott <nathans@sgi.com>2002-09-06 03:15:41 +0000
commit363a80be1e53dabc0da1df243bab9c158d7878a4 (patch)
tree0bd07e782298dac76a4c2e4de136811c25c2aa16 /setfacl
parent43ceb48dc022f3c9eccbb25d7338a0e96490fc8d (diff)
downloadacl-363a80be1e53dabc0da1df243bab9c158d7878a4.tar.gz
updates from Andreas.
Diffstat (limited to 'setfacl')
-rw-r--r--setfacl/do_set.c8
-rw-r--r--setfacl/setfacl.c13
2 files changed, 8 insertions, 13 deletions
diff --git a/setfacl/setfacl.c b/setfacl/setfacl.c
index 995c493..0dad1ab 100644
--- a/setfacl/setfacl.c
+++ b/setfacl/setfacl.c
@@ -49,8 +49,8 @@ do_set(
/* '-' stands for `process non-option arguments in loop' */
#if !POSIXLY_CORRECT
-# define CMD_LINE_OPTIONS "-:bknds:S:m:M:x:X:RLP"
-# define CMD_LINE_SPEC "[-bkndRLP] { -s|-S|-m|-M|-x|-X ... } file ..."
+# define CMD_LINE_OPTIONS "-:bkndm:M:x:X:RLP"
+# define CMD_LINE_SPEC "[-bkndRLP] { -m|-M|-x|-X ... } file ..."
#endif
#define POSIXLY_CMD_LINE_OPTIONS "-:bkndm:M:x:X:"
#define POSIXLY_CMD_LINE_SPEC "[-bknd] {-m|-M|-x|-X ... } file ..."
@@ -230,13 +230,6 @@ void help(void)
progname, VERSION);
printf(_("Usage: %s %s\n"),
progname, cmd_line_spec);
-#if !POSIXLY_CORRECT
- if (!posixly_correct) {
- printf(_(
-" -s, --set=acl set the ACL of file(s), replacing the current ACL\n"
-" -S, --set-file=file read ACL entries to set from file\n"));
- }
-#endif
printf(_(
" -m, --modify=acl modify the current ACL(s) of file(s)\n"
" -M, --modify-file=file read ACL entries to modify from file\n"
@@ -247,6 +240,8 @@ void help(void)
#if !POSIXLY_CORRECT
if (!posixly_correct) {
printf(_(
+" --set=acl set the ACL of file(s), replacing the current ACL\n"
+" --set-file=file read ACL entries to set from file\n"
" --mask do recalculate the effective rights mask\n"));
}
#endif
diff --git a/setfacl/do_set.c b/setfacl/do_set.c
index 223e7c9..ae4b296 100644
--- a/setfacl/do_set.c
+++ b/setfacl/do_set.c
@@ -379,7 +379,7 @@ do_set(
goto fail;
if (error > 0) {
acl_text = acl_to_any_text(acl, NULL, ',', 0);
- fprintf(stderr, _("%s: %s: Resulting ACL `%s': "
+ fprintf(stderr, _("%s: %s: Malformed ACL `%s': "
"%s at entry %d\n"), progname, path_p,
acl_text, acl_error(error), which_entry+1);
acl_free(acl_text);
@@ -406,7 +406,7 @@ do_set(
goto fail;
if (error > 0) {
acl_text = acl_to_any_text(default_acl, NULL, ',', 0);
- fprintf(stderr, _("%s: %s: Resulting default ACL "
+ fprintf(stderr, _("%s: %s: Malformed default ACL "
"`%s': %s at entry %d\n"),
progname, path_p, acl_text,
acl_error(error), which_entry+1);
@@ -416,7 +416,7 @@ do_set(
}
}
/* Only directores can have a default ACL */
if (default_acl && !S_ISDIR(st->st_mode) && opt_recursive) {
/* In recursive mode, ignore default ACLs for files */
acl_free(default_acl);
@@ -469,7 +469,7 @@ do_set(
} else {
if (acl_entries(default_acl) != 0) {
fprintf(stderr, _("%s: %s: Only directories "
- "can have a default ACL\n"),
+ "can have default ACLs\n"),
progname, path_p);
errors++;
goto cleanup;
@@ -416,7 +416,7 @@ do_set(
}
}
- /* Only directores can have a default ACL */
+ /* Only directores can have default ACLs */
if (default_acl && !S_ISDIR(st->st_mode) && opt_recursive) {
/* In recursive mode, ignore default ACLs for files */